==> appmesh-1.93.0-sources.jar: software/amazon/awscdk/services/appmesh/VirtualRouterProps.java <==
package software.amazon.awscdk.services.appmesh;

/**
 * (experimental) The properties used when creating a new VirtualRouter.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.24.0 (build b722f66)", date = "2021-03-11T13:47:05.109Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.appmesh.$Module.class, fqn = "@aws-cdk/aws-appmesh.VirtualRouterProps")
@software.amazon.jsii.Jsii.Proxy(VirtualRouterProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface VirtualRouterProps extends software.amazon.jsii.JsiiSerializable, software.amazon.awscdk.services.appmesh.VirtualRouterBaseProps {

    /**
     * (experimental) The Mesh which the VirtualRouter belongs to.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.appmesh.IMesh getMesh();

    /**
     * @return a {@link Builder} of {@link VirtualRouterProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link VirtualRouterProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<VirtualRouterProps> {
        private software.amazon.awscdk.services.appmesh.IMesh mesh;
        private java.util.List<software.amazon.awscdk.services.appmesh.VirtualRouterListener> listeners;
        private java.lang.String virtualRouterName;

        /**
         * Sets the value of {@link VirtualRouterProps#getMesh}
         * @param mesh The Mesh which the VirtualRouter belongs to. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder mesh(software.amazon.awscdk.services.appmesh.IMesh mesh) {
            this.mesh = mesh;
            return this;
        }

        /**
         * Sets the value of {@link VirtualRouterProps#getListeners}
         * @param listeners Listener specification for the VirtualRouter.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @SuppressWarnings("unchecked")
        public Builder listeners(java.util.List<? extends software.amazon.awscdk.services.appmesh.VirtualRouterListener> listeners) {
            this.listeners = (java.util.List<software.amazon.awscdk.services.appmesh.VirtualRouterListener>)listeners;
            return this;
        }

        /**
         * Sets the value of {@link VirtualRouterProps#getVirtualRouterName}
         * @param virtualRouterName The name of the VirtualRouter.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder virtualRouterName(java.lang.String virtualRouterName) {
            this.virtualRouterName = virtualRouterName;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link VirtualRouterProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public VirtualRouterProps build() {
            return new Jsii$Proxy(mesh, listeners, virtualRouterName);
        }
    }

    /**
     * An implementation for {@link VirtualRouterProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements VirtualRouterProps {
        private final software.amazon.awscdk.services.appmesh.IMesh mesh;
        private final java.util.List<software.amazon.awscdk.services.appmesh.VirtualRouterListener> listeners;
        private final java.lang.String virtualRouterName;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.mesh = software.amazon.jsii.Kernel.get(this, "mesh", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.appmesh.IMesh.class));
            this.listeners = software.amazon.jsii.Kernel.get(this, "listeners", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.appmesh.VirtualRouterListener.class)));
            this.virtualRouterName = software.amazon.jsii.Kernel.get(this, "virtualRouterName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        @SuppressWarnings("unchecked")
        protected Jsii$Proxy(final software.amazon.awscdk.services.appmesh.IMesh mesh, final java.util.List<? extends software.amazon.awscdk.services.appmesh.VirtualRouterListener> listeners, final java.lang.String virtualRouterName) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.mesh = java.util.Objects.requireNonNull(mesh, "mesh is required");
            this.listeners = (java.util.List<software.amazon.awscdk.services.appmesh.VirtualRouterListener>)listeners;
            this.virtualRouterName = virtualRouterName;
        }

        @Override
        public final software.amazon.awscdk.services.appmesh.IMesh getMesh() {
            return this.mesh;
        }

        @Override
        public final java.util.List<software.amazon.awscdk.services.appmesh.VirtualRouterListener> getListeners() {
            return this.listeners;
        }

        @Override
        public final java.lang.String getVirtualRouterName() {
            return this.virtualRouterName;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("mesh", om.valueToTree(this.getMesh()));
            if (this.getListeners() != null) {
                data.set("listeners", om.valueToTree(this.getListeners()));
            }
            if (this.getVirtualRouterName() != null) {
                data.set("virtualRouterName", om.valueToTree(this.getVirtualRouterName()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-appmesh.VirtualRouterProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            VirtualRouterProps.Jsii$Proxy that = (VirtualRouterProps.Jsii$Proxy) o;

            if (!mesh.equals(that.mesh)) return false;
            if (this.listeners != null ? !this.listeners.equals(that.listeners) : that.listeners != null) return false;
            return this.virtualRouterName != null ? this.virtualRouterName.equals(that.virtualRouterName) : that.virtualRouterName == null;
        }

        @Override
        public final int hashCode() {
            int result = this.mesh.hashCode();
            result = 31 * result + (this.listeners != null ? this.listeners.hashCode() : 0);
            result = 31 * result + (this.virtualRouterName != null ? this.virtualRouterName.hashCode() : 0);
            return result;
        }
    }
}

==> appmesh-1.182.0-sources.jar: software/amazon/awscdk/services/appmesh/VirtualRouterProps.java <==
package software.amazon.awscdk.services.appmesh;

/**
 * The properties used when creating a new VirtualRouter.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * Stack infraStack;
 * Stack appStack;
 * Mesh mesh = Mesh.Builder.create(infraStack, "AppMesh")
 *         .meshName("myAwsMesh")
 *         .egressFilter(MeshFilterType.ALLOW_ALL)
 *         .build();
 * // the VirtualRouter will belong to 'appStack',
 * // even though the Mesh belongs to 'infraStack'
 * VirtualRouter router = VirtualRouter.Builder.create(appStack, "router")
 *         .mesh(mesh) // notice that mesh is a required property when creating a router with the 'new' statement
 *         .listeners(List.of(VirtualRouterListener.http(8081)))
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.71.0 (build f1f58ae)", date = "2022-12-07T17:24:46.369Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.appmesh.$Module.class, fqn = "@aws-cdk/aws-appmesh.VirtualRouterProps")
@software.amazon.jsii.Jsii.Proxy(VirtualRouterProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface VirtualRouterProps extends software.amazon.jsii.JsiiSerializable, software.amazon.awscdk.services.appmesh.VirtualRouterBaseProps {

    /**
     * The Mesh which the VirtualRouter belongs to.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.appmesh.IMesh getMesh();

    /**
     * @return a {@link Builder} of {@link VirtualRouterProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link VirtualRouterProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<VirtualRouterProps> {
        software.amazon.awscdk.services.appmesh.IMesh mesh;
        java.util.List<software.amazon.awscdk.services.appmesh.VirtualRouterListener> listeners;
        java.lang.String virtualRouterName;

        /**
         * Sets the value of {@link VirtualRouterProps#getMesh}
         * @param mesh The Mesh which the VirtualRouter belongs to. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder mesh(software.amazon.awscdk.services.appmesh.IMesh mesh) {
            this.mesh = mesh;
            return this;
        }

        /**
         * Sets the value of {@link VirtualRouterProps#getListeners}
         * @param listeners Listener specification for the VirtualRouter.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @SuppressWarnings("unchecked")
        public Builder listeners(java.util.List<? extends software.amazon.awscdk.services.appmesh.VirtualRouterListener> listeners) {
            this.listeners = (java.util.List<software.amazon.awscdk.services.appmesh.VirtualRouterListener>)listeners;
            return this;
        }

        /**
         * Sets the value of {@link VirtualRouterProps#getVirtualRouterName}
         * @param virtualRouterName The name of the VirtualRouter.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder virtualRouterName(java.lang.String virtualRouterName) {
            this.virtualRouterName = virtualRouterName;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link VirtualRouterProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public VirtualRouterProps build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link VirtualRouterProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements VirtualRouterProps {
        private final software.amazon.awscdk.services.appmesh.IMesh mesh;
        private final java.util.List<software.amazon.awscdk.services.appmesh.VirtualRouterListener> listeners;
        private final java.lang.String virtualRouterName;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.mesh = software.amazon.jsii.Kernel.get(this, "mesh", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.appmesh.IMesh.class));
            this.listeners = software.amazon.jsii.Kernel.get(this, "listeners", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.appmesh.VirtualRouterListener.class)));
            this.virtualRouterName = software.amazon.jsii.Kernel.get(this, "virtualRouterName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        @SuppressWarnings("unchecked")
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.mesh = java.util.Objects.requireNonNull(builder.mesh, "mesh is required");
            this.listeners = (java.util.List<software.amazon.awscdk.services.appmesh.VirtualRouterListener>)builder.listeners;
            this.virtualRouterName = builder.virtualRouterName;
        }

        @Override
        public final software.amazon.awscdk.services.appmesh.IMesh getMesh() {
            return this.mesh;
        }

        @Override
        public final java.util.List<software.amazon.awscdk.services.appmesh.VirtualRouterListener> getListeners() {
            return this.listeners;
        }

        @Override
        public final java.lang.String getVirtualRouterName() {
            return this.virtualRouterName;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("mesh", om.valueToTree(this.getMesh()));
            if (this.getListeners() != null) {
                data.set("listeners", om.valueToTree(this.getListeners()));
            }
            if (this.getVirtualRouterName() != null) {
                data.set("virtualRouterName", om.valueToTree(this.getVirtualRouterName()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-appmesh.VirtualRouterProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            VirtualRouterProps.Jsii$Proxy that = (VirtualRouterProps.Jsii$Proxy) o;

            if (!mesh.equals(that.mesh)) return false;
            if (this.listeners != null ? !this.listeners.equals(that.listeners) : that.listeners != null) return false;
            return this.virtualRouterName != null ? this.virtualRouterName.equals(that.virtualRouterName) : that.virtualRouterName == null;
        }

        @Override
        public final int hashCode() {
            int result = this.mesh.hashCode();
            result = 31 * result + (this.listeners != null ? this.listeners.hashCode() : 0);
            result = 31 * result + (this.virtualRouterName != null ? this.virtualRouterName.hashCode() : 0);
            return result;
        }
    }
}
